function [P_propagada, x_propagada] = filtreKalman_I_Prediccio( t,...
    C_e_b_vella, f_b_ib, r_e_eb_vella, P_vella)
%FILTREKALMAN_I_PREDICCIO: Executa l'etapa de predicci del filtre de
%Kalman.
%Inputs:
%       t: temps d'iteraci (s).    
%       C_e_b_vella: Matriu de rotaci de body a ECEF.
%       f_b_ib: fora especfica que llegeix la IMU.
%       r_e_eb_vella: posici en coordenades ECEF (m).
%       P_vella: matriu de covariana anterior.
%
%Outputs:
%       x_propagada: vector d'estat.
%       P_propagada: Covariance matrix de l'etapa de predicci.

    Ro = 6378137;
    e = 0.0818191908425;
    w_ie = 7.292115e-5;
    MatriuVelocitatTerra = [0 -w_ie 0; w_ie 0 0; 0 0 0];
    
    %Definirem un per un tots els pasos per aplicar correctament l'etapa de
    %predicci del filtre de Kalman.
    
    %PAS 1: Calcular la matriu de transisi (transition matrix) (Phi).
    
    f_e_21 = -C_e_b_vella*f_b_ib;
    F_e_21 = [0 -f_e_21(3) f_e_21(2); f_e_21(3) 0 -f_e_21(1); -f_e_21(2)...
        f_e_21(1) 0];
    
    [L, lambda, h] = Borkowski(r_e_eb_vella(1), r_e_eb_vella(2),...
        r_e_eb_vella(3));
       
    [g, gamma] = gravetat_ECEF(r_e_eb_vella(1), r_e_eb_vella(2),...
        r_e_eb_vella(3));
    
    r_e_eS = Ro/sqrt(1 - (e*sin(L))^2)*sqrt(cos(L)^2 + ...
        (1 - e^2)^2*sin(L)^2);
    
    F_e_23 = -2*g*r_e_eb_vella'/(r_e_eS*sqrt(r_e_eb_vella'*r_e_eb_vella));
    
    
    Phi = eye(15);
    Phi(1:3,1:3) = Phi(1:3,1:3) - MatriuVelocitatTerra*t;
    Phi(1:3, 13:15) = C_e_b_vella*t;
    Phi(4:6, 1:3) = F_e_21*t;
    Phi(4:6, 4:6) = Phi(4:6, 4:6) - 2*MatriuVelocitatTerra*t;
    Phi(4:6, 7:9) = F_e_23*t;
    Phi(4:6, 10:12) = C_e_b_vella*t;
    Phi(7:9, 4:6) = eye(3)*t;
   
    %PAS 2: System noise covariance matrix 
    
    LC_KF_gyro_noise_PSD = 0.000007^2;             
    LC_KF_accel_noise_PSD = 0.002^2;
    LC_KF_accel_bias_PSD = 1.0E-7;
    LC_KF_gyro_bias_PSD = 4.0E-12;
    
    Q = zeros(15);
    Q(1:3, 1:3) = eye(3)*LC_KF_gyro_noise_PSD * t;
    Q(4:6, 4:6) = eye(3)*LC_KF_accel_noise_PSD * t;
    Q(10:12, 10:12) = eye(3)*LC_KF_accel_bias_PSD * t;
    Q(13:15, 13:15) = eye(3)* LC_KF_gyro_bias_PSD * t;
    
    %PAS 3: Propagar l'estimaci d'estat.
    
    x_propagada(1:15,1) = 0;
    
    %PAS 4: Calcular covariance matrix.
    
    P_propagada = Phi*(P_vella + 0.5*Q)*Phi' + 0.5*Q;

end

